@@ -54,9 +54,9 @@ copyright = '2008, Repoze Developers <repoze-dev@lists.repoze.org>'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '0.9.1'
+version = '0.10'
 # The full version, including alpha/beta/rc tags.
-release = '0.9.1'
+release = '0.10'
 
 # There are two options for replacing |today|: either, you set today to
 # some non-false value, then it is used:
