@@ -1,5 +1,7 @@
-import urlparse
-from repoze.zodbconn.resolvers import RESOLVERS
+
+from repoze.zodbconn.uri import db_from_uri
+from repoze.zodbconn.uri import dbfactory_from_uri  # BBB
+from repoze.zodbconn.connector import CONNECTION_KEY
 
 class SimpleCleanup:
     def __init__(self, conn, environ):
@@ -41,39 +43,32 @@ class LoggingCleanup:
 class PersistentApplicationFinder:
     db = None
 
-    def __init__(self, uris, appmaker, cleanup=SimpleCleanup):
-        if isinstance(uris, basestring):
-            uris = uris.split()
-        self.uris = uris
+    def __init__(self, uri, appmaker, cleanup=SimpleCleanup,
+            connection_key=CONNECTION_KEY):
+        self.uri = uri
         self.appmaker = appmaker
+        self.connection_key = connection_key
         self.cleanup = cleanup
 
     def __call__(self, environ):
-        if self.db is None:
-            databases = {}
-            for uri in self.uris:
-                dbfactory = dbfactory_from_uri(uri)
-                db = dbfactory()
-                if db.database_name in databases:
-                    raise ValueError("database_name %r already in databases" %
-                        db.database_name)
-                # link the databases together
-                databases[db.database_name] = db
-                db.databases = databases
-                if self.db is None:
-                    # the first database in the list of URIs is the root
-                    self.db = db
-        conn = self.db.open()
+        conn = None
+        if self.connection_key:
+            conn = environ.get(self.connection_key)
+
+        if conn is not None:
+            from_environ = True
+        else:
+            from_environ = False
+            if self.db is None:
+                self.db = db_from_uri(self.uri)
+            conn = self.db.open()
+
         root = conn.root()
         app = self.appmaker(root)
-        environ['repoze.zodbconn.closer'] = self.cleanup(conn, environ)
+
+        if not from_environ:
+            environ['repoze.zodbconn.closer'] = self.cleanup(conn, environ)
+        # Otherwise, something else opened the connection and it
+        # has the responsibility to close it.
+
         return app
-
-def dbfactory_from_uri(uri):
-    (scheme, netloc, path, query, frag) = urlparse.urlsplit(uri)
-    resolver =  RESOLVERS.get(scheme)
-    if resolver is None:
-        raise ValueError('Unresolveable URI %s' % uri)
-    _, _, _, dbfactory = resolver(uri)
-    return dbfactory
-
